@@ -4,4 +4,6 @@ from .authenticator import Authenticator
 from .bulk_data import BulkData
 from .hfn import HighFrequencyNews
 from .quotes import Quotes
-from .intraday_tick_data import IntradayTickData
\ No newline at end of file
+from .intraday_tick_data import IntradayTickData
+from .ticker_last_event import TickerLastEvent
+from .corporate_events import CorporateEvents
\ No newline at end of file
